#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/eeprom.h>
#include <stdlib.h>
#include "rf12.h"
#include "usart.h"

#define F_CPU 	10000000UL	// 16000000UL
#include <util/delay.h>

#define TASTER_DDR	PORTB
#define TASTER_PIN	PINB
#define TASTER_PORT	PORTB
#define TASTER0		1

#define LED_PORT	PORTD
#define LED_DDR		DDRD

#define LED1		6
#define LED2		5
#define LEDOPTO		4	//	PORTD4	- POWER

	//	PORTD0 AVR-RX
	//	PORTD1 AVR-TX

void init(void);
void receive(void);
void send(void);

int main(void)
{
	init();
	
	sei();
		
	while(1)
	{
		if ((TASTER_PIN & (1<<TASTER0))) // Falls Tastendruck
		{
			LED_PORT |= (1<<LED1);		// LED einschalten
		}
		send();
	}
}

void init(void)
{
	LED_DDR |= (1<<LEDOPTO)|(1<<LED2)|(1<<LED1);	// LEDs einstellen
	LED_PORT |= (1<<LEDOPTO);		// Funkmodul Strom einschalten

	TASTER_DDR &= ~(1<<TASTER0);		// Taster einstellen
	TASTER_PORT &= ~(1<<TASTER0);	// Pullup ausschalten

	usart_init(); 		// Serielle Schnittstelle initialisieren
	usart_write("Serial TEST\r\n"); 

	rf12_init();					// ein paar Register setzen (z.B. CLK auf 10MHz)					// ein paar Register setzen (z.B. CLK auf 10MHz)
	rf12_setfreq(RF12FREQ(433.92));	// Sende/Empfangsfrequenz auf 433,92MHz einstellen
	rf12_setbandwidth(RxBW200, LNA_6, RSSI_79);		// 200kHz Bandbreite, -6dB Verstrkung, DRSSI threshold: -79dBm 
	rf12_setbaud(9600);				// 9600 baud
	rf12_setpower(PWRdB_0, TxBW105);			// 1mW Ausgangangsleistung, 120kHz Frequenzshift

	unsigned char i;
	for (i=0; i<3; i++)	// PowerUp Blinken
	{	
		LED_PORT &= ~(1<<LED2);		// LED ausschalten
		_delay_ms(100);
		LED_PORT |= (1<<LED2);		// LED einschalten
		_delay_ms(100);
	}
}

void receive(void)
{
	unsigned char ret;
	//unsigned char test[50];
	unsigned char test2[50];

	usart_write("Startwert: ");
	usart_write_char(rf12_rxstart());
	usart_write("\r\n");

	ret = 255;				//not completed yet
	while(ret == 255)
	{
		ret = rf12_rxfinish(test2);	//try if transfer completed
	}
		
	usart_write("Rckgabewert: ");
	usart_write_char(ret);
	usart_write("\r\n");
	
	if(ret != 0 && ret != 254)				//no CRC error && no old str
	{
		usart_write("Empfangen: ");
		usart_write((char*)test2);
		usart_write("\r\n");
	}
}
void send(void)
{
	if ((TASTER_PIN&(1<<TASTER0))) // Falls Tastendruck: senden
	{
    	unsigned char i;
    	
    	usart_write("Pkg\n");
    	
    	unsigned char test[]="Dies ist ein 433MHz Test !!!\n";	
    	    	
    	usart_write((char*)test);
		usart_write("\r\n");
    
    	usart_write("Start...\n");
    	
    	rf12_txstart(test, 29);
    	
    	while(rf12_txfinished());

    	usart_write("Done\r\n");
    	
    	for (i=0; i<2; i++)
        {	
        	LED_PORT |= (1<<LED1);		// LED einschalten
        	_delay_ms(10);
        	LED_PORT &= ~(1<<LED1);		// LED ausschalten
        	_delay_ms(10);
		}
    
    	for (i=0; i<100; i++)
    	{
    		_delay_ms(10);
    	}
    }
}
